pygeodesy.azimuthal._AzimuthalGeodesic

Package pygeodesy :: Module azimuthal :: Class _AzimuthalGeodesic |
[frames] | no frames]

# Class _AzimuthalGeodesic

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
          _AzimuthalBase --+
                           |
                          _AzimuthalGeodesic

Known Subclasses:
  - _EquidistantBase
  - , _GnomonicBase

(INTERNAL) Base class for azimuthal projections using the wrapped geodesic.Geodesic and geodesicline.GeodesicLine or the exact geodesic classes GeodesicExact and GeodesicLineExact.

Instance Methods
Inherited from `_AzimuthalBase`: `__init__`, `forward`, `reset`, `reverse`, `toRepr`, `toStr` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| geodesic Must be overloaded.
Inherited from `_AzimuthalBase`: `a`, `datum`, `equatoradius`, `f`, `flattening`, `lat0`, `latlon0`, `lon0`, `majoradius`, `radius` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Property Details

### geodesic Must be overloaded. Get method: geodesic(self) - Must be overloaded. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.